@@ -47,7 +47,12 @@ bool dateMoreThan(const Score *s1, const Score *s2)
 
 bool scoreMoreThan(const Score *s1, const Score *s2)
 {
-    return s1->getTotal(Total) > s2->getTotal(Total);
+    return s1->getTotal(Total).toInt() > s2->getTotal(Total).toInt();
+}
+
+bool scoreLessThan(const Score *s1, const Score *s2)
+{
+    return s1->getTotal(Total).toInt() < s2->getTotal(Total).toInt();
 }
 
 // Find score based on club and course name
@@ -167,7 +172,7 @@ void MainWindow::sortScoreList()
     if (conf.sortOrder == "Date")
         qSort(scoreList.begin(), scoreList.end(), dateMoreThan); 
     else if (conf.sortOrder == "Score")
-        qSort(scoreList.begin(), scoreList.end(), scoreMoreThan); 
+        qSort(scoreList.begin(), scoreList.end(), scoreLessThan); 
 }
 
 MainWindow::MainWindow(QMainWindow *parent): QMainWindow(parent)
@@ -251,7 +256,7 @@ void MainWindow::loadSettings(void)
 
     // Use date sort order if no settings for that
     if (!conf.sortOrder.isValid())
-        conf.sortOrder = "Yes";
+        conf.sortOrder = "Date";
 
     qDebug() << "Settings: " << conf.hcp << conf.homeClub << conf.sortOrder << conf.defaultCourses;
 }
