@@ -32,14 +32,16 @@ private slots:
 
 private:
     void createLayout(QWidget *parent);
-    QStandardItemModel *homeClubModel;
     QStandardItemModel *hcpModel;
+    QStandardItemModel *homeClubModel;
+    QStandardItemModel *sortModel;
     QStandardItemModel *defaultCoursesModel;
 
     QList<Club *> clubList;
 #ifdef Q_WS_MAEMO_5
     QMaemo5ValueButton * hcpButton;
     QMaemo5ValueButton * homeClubButton;
+    QMaemo5ValueButton * sortButton;
     QMaemo5ValueButton * defaultCoursesButton;
 #endif
 };
