@@ -7,7 +7,9 @@
  */
 
 #include <QVariant>
+#include <QFont>
 
+#include "score-common.h"
 #include "stat-model.h"
 
 StatModel::StatModel(QList<Club *> &cList, QList<Score *> &sList) : clubList(cList), scoreList(sList)
@@ -45,6 +47,14 @@ QVariant StatModel::data(const QModelIndex & index, int role) const
     return Qt::AlignCenter;
   }
 
+  //
+  // FONT
+  //
+  if (role == Qt::FontRole) {
+      QFont font;
+      font.setPointSize(fontSize);
+      return font;
+  }
   //
   // NUMBERS
   //
